@@ -5,8 +5,12 @@
  *  Do all the initialization stuff.  For daemon mode, only
  *  children will return.
  *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  *  This file is part of AutoGen.
- *  Copyright (C) 1992-2013 Bruce Korb - all rights reserved
+ *  Copyright (C) 1992-2015 Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -39,8 +43,8 @@ add_sys_env(char * env_name);
 /* = = = END-STATIC-FORWARD = = = */
 
 #ifdef DAEMON_ENABLED
- static bool evalProto(char const ** ppzS, uint16_t* pProto);
- static void spawnPipe(char const* pzFile);
+ static bool evalProto(char const ** ppzS, uint16_t * pProto);
+ static void spawnPipe(char const * pzFile);
  static void spawnListens(char const * pzPort, sa_family_t af);
  static void daemonize(char const *, char const *, char const *,
                        char const *);
@@ -55,11 +59,11 @@ add_sys_env(char * env_name);
  * @param arg_vec the program name plus its arguments
  */
 LOCAL void
-initialize(int arg_ct, char** arg_vec)
+initialize(int arg_ct, char ** arg_vec)
 {
     putenv(C(char *, ld_lib_path));
 
-    ag_scribble_init();
+    scribble_init();
 
     /*
      *  Initialize all the Scheme functions.
@@ -71,7 +75,7 @@ initialize(int arg_ct, char** arg_vec)
     processing_state = PROC_STATE_OPTIONS;
 
     process_ag_opts(arg_ct, arg_vec);
-    exit_code = AUTOGEN_EXIT_LOAD_ERROR;
+    ag_exit_code = AUTOGEN_EXIT_LOAD_ERROR;
 
     if (OPT_VALUE_TRACE > TRACE_NOTHING)
         SCM_EVAL_CONST(INIT_SCM_DEBUG_FMT);
@@ -349,9 +353,11 @@ prep_env(void)
      *  Set the last resort search directories first (lowest priority)
      *  The lowest of the low is the config time install data dir.
      *  Next is the *current* directory of this executable.
+     *  Last (highest priority) of the low priority is the library data dir.
      */
     SET_OPT_TEMPL_DIRS(DFT_TPL_DIR_DATA);
     SET_OPT_TEMPL_DIRS(DFT_TPL_DIR_RELATIVE);
+    SET_OPT_TEMPL_DIRS(LIBDATADIR);
 
     {
         char z[ SCRIBBLE_SIZE ] = "__autogen__";
@@ -408,12 +414,12 @@ prep_env(void)
 #ifdef DAEMON_ENABLED
 
   static bool
-evalProto(char const ** ppzS, uint16_t* pProto)
+evalProto(char const ** ppzS, uint16_t * pProto)
 {
     char const * pzS = *ppzS;
 
     if (IS_ALPHABETIC_CHAR(*pzS)) {
-        inet_family_map_t* pMap = inet_family_map;
+        inet_family_map_t * pMap = inet_family_map;
         do  {
             if (strncmp(pzS, pMap->pz_name, pMap->nm_len) == 0) {
                 *pProto = pMap->family;
@@ -438,8 +444,8 @@ spawnPipe(char const * pzFile)
 #   define S_IRW_ALL \
         S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH
     fd_pair_t fdpair;
-    char* pzIn;
-    char* pzOut;
+    char * pzIn;
+    char * pzOut;
 
     {
         size_t len = 2 * (strlen(pzFile) + 5);
@@ -524,7 +530,7 @@ spawnPipe(char const * pzFile)
 
 #   undef S_IRW_ALL
 
-    exit(EXIT_SUCCESS);
+    exit(AUTOGEN_EXIT_SUCCESS);
 }
 
 
@@ -560,7 +566,7 @@ spawnListens(char const * pzPort, sa_family_t addr_family)
     case AF_INET:
     {
         uint16_t port;
-        char* pz;
+        char * pz;
 
         sa.in_addr.sin_family      = AF_INET;
         sa.in_addr.sin_addr.s_addr = INADDR_ANY;
@@ -583,7 +589,7 @@ spawnListens(char const * pzPort, sa_family_t addr_family)
     }
 
     if (bind(socket_fd, &sa.addr, addr_len) < 0) {
-        char* pz = aprf(LISTEN_PORT_FMT, pzPort, addr_family);
+        char * pz = aprf(LISTEN_PORT_FMT, pzPort, addr_family);
         AG_CANT("bind", pz);
     }
 
@@ -608,7 +614,7 @@ spawnListens(char const * pzPort, sa_family_t addr_family)
 
             if (! redoOptions) {
                 unlink(pzPort);
-                exit(EXIT_SUCCESS);
+                exit(AUTOGEN_EXIT_SUCCESS);
             }
 
             optionRestore(&autogenOptions);
@@ -674,9 +680,11 @@ daemonize(char const * pzStdin, char const * pzStdout, char const * pzStderr,
 
         switch (ret) {
         case -1:
-            fprintf(stderr, FORK_FAILED, errno, strerror(errno));
+            fserr(AUTOGEN_EXIT_FS_ERROR, "fork", "");
+            /* NOTREACHED */
+
         default:
-            exit(ret);
+            exit(AUTOGEN_EXIT_SUCCESS);
 
         case 0:
             break;
@@ -686,10 +694,8 @@ daemonize(char const * pzStdin, char const * pzStdout, char const * pzStderr,
     /*
      *  Now, become a process group and session group leader.
      */
-    if (setsid() == -1) {
-        fprintf(stderr, SETSID_FAIL, errno, strerror(errno));
-        exit(99);
-    }
+    if (setsid() == -1)
+        fserr(AUTOGEN_EXIT_FS_ERROR, "setsid", "");
 
     /*
      *  There is now no controlling terminal.  However, if we open anything
@@ -699,18 +705,17 @@ daemonize(char const * pzStdin, char const * pzStdout, char const * pzStderr,
      */
     switch (fork()) {
     case -1:
-        fprintf(stderr, FORK_FAILED, errno, strerror(errno));
-        exit(99);
+        fserr(AUTOGEN_EXIT_FS_ERROR, "fork", "");
+
+    default:
+        exit(AUTOGEN_EXIT_SUCCESS);  /* parent process - silently go away */
 
     case 0:
         break;
-
-    default:
-        exit(EXIT_SUCCESS);  /* parent process - silently go away */
     }
 
     umask(0);
-    if (pzDaemonDir == (char*)NULL)
+    if (pzDaemonDir == (char *)NULL)
         pzDaemonDir = "/";
 
     chdir(pzDaemonDir);
@@ -718,19 +723,21 @@ daemonize(char const * pzStdin, char const * pzStdout, char const * pzStderr,
     /*
      *  Reopen the input, output and error files, unless we were told not to
      */
-    if (pzStdin != (char*)NULL)
+    if (pzStdin != (char *)NULL)
         freopen(pzStdin,  "r", stdin);
 
-    if (pzStdout != (char*)NULL)
+    if (pzStdout != (char *)NULL)
         freopen(pzStdout, "w", stdout);
 
-    if (pzStderr != (char*)NULL)
+    if (pzStderr != (char *)NULL)
         freopen(pzStderr, "w", stderr);
 
     /* We are a daemon now */
 }
 #endif /* DAEMON_ENABLED */
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
