@@ -5,10 +5,14 @@
  *  Find the start and end macro markers.  In btween we must find the
  *  "autogen" and "template" keywords, followed by any suffix specs.
  *
- *  This module processes the "pseudo" macro
+ *  This module processes the "pseudo" macro.
  *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2015 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -51,19 +55,19 @@ copy_mark(char const * text, char * marker, size_t * ret_ct);
 static char const *
 do_scheme_expr(char const * text, char const * fname)
 {
-    char *    pzEnd = (char*)text + strlen(text);
+    char *    pzEnd = (char *)text + strlen(text);
     char      ch;
     macro_t * pCM   = cur_macro;
     macro_t   mac   = { (mac_func_t)~0, 0, 0, 0, 0, 0, 0, NULL };
 
     mac.md_line = tpl_line;
-    pzEnd       = (char*)skip_scheme(text, pzEnd);
+    pzEnd       = (char *)skip_scheme(text, pzEnd);
     ch          = *pzEnd;
     *pzEnd      = NUL;
     cur_macro   = &mac;
 
     ag_scm_c_eval_string_from_file_line(
-          (char*)text, fname, tpl_line );
+          (char *)text, fname, tpl_line );
 
     cur_macro = pCM;
     *pzEnd    = ch;
@@ -90,7 +94,7 @@ do_suffix(char const * const text, char const * fname, int lineNo)
      *  also allow a format specification to follow the suffix,
      *  separated by an '=' character.
      */
-    out_spec_t   *       pOS;
+    out_spec_t *       pOS;
     char const *       pzSfxFmt;
     char const *       pzResult;
     size_t             spn;
@@ -217,7 +221,7 @@ handle_hash_line(char const * pz)
         pzScn = SPN_FILE_NAME_CHARS(pzScn);
 
         len   = (size_t)(pzScn - (pz + 2));
-        nmbuf = ag_scribble((ssize_t)len);
+        nmbuf = scribble_get((ssize_t)len);
         memcpy(nmbuf, pz+2, len);
         nmbuf[len] = NUL;
 
@@ -384,9 +388,13 @@ copy_mark(char const * text, char * marker, size_t * ret_ct)
 /**
  *  Using a finite state machine, scan over the tokens that make up the
  *  "pseudo macro" at the start of every template.
+ *
+ *  @param[in,out]  text    text of template
+ *  @param[in]      fname   name of template file
+ *  @returns the address of the byte following the pseudo macro
  */
 LOCAL char const *
-loadPseudoMacro(char const * text, char const * fname)
+load_pseudo_mac(char const * text, char const * fname)
 {
     char const * pzBadness;
 #   define BAD_MARKER(t) { pzBadness = t; goto abort_load; }
@@ -411,8 +419,8 @@ loadPseudoMacro(char const * text, char const * fname)
         switch (trans) {
         case PM_TR_SKIP_ED_MODE:
         {
-            char* pzEnd = strstr(text + 3, PSEUDO_MAC_MODE_MARK);
-            char* pzNL  = strchr(text + 3, NL);
+            char * pzEnd = strstr(text + 3, PSEUDO_MAC_MODE_MARK);
+            char * pzNL  = strchr(text + 3, NL);
             if ((pzEnd == NULL) || (pzNL < pzEnd))
                 BAD_MARKER(PSEUDO_MAC_BAD_MODE);
 
@@ -486,7 +494,9 @@ loadPseudoMacro(char const * text, char const * fname)
 #   undef BAD_MARKER
     return NULL;
 }
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
