@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sat May 17 07:50:07 PDT 2014
+ * Generated Thu Apr 30 19:55:38 PDT 2015
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -57,15 +57,12 @@ shell_cmd(char const * cmd);
 /*
  *  Extracted from agUtils.c
  */
+static void
+fswarn(char const * op, char const * fname);
+
 static char *
 aprf(char const * pzFmt, ...);
 
-static void
-open_trace_file(char ** av, tOptDesc * odsc);
-
-static void
-check_make_dep_env(void);
-
 static void
 process_ag_opts(int arg_ct, char ** arg_vec);
 
@@ -78,11 +75,8 @@ span_quote(char * in_q);
 static char const *
 skip_scheme(char const * scan,  char const * end);
 
-static int
-count_nl(char const * pz);
-
 static char const *
-skip_expr(char const * pzSrc, size_t len);
+skip_expr(char const * src, size_t len);
 
 /*
  *  Extracted from autogen.c
@@ -131,7 +125,7 @@ static te_dp_event
 yylex(void);
 
 static void
-yyerror(char* s);
+yyerror(char * s);
 
 /*
  *  Extracted from defLoad.c
@@ -215,11 +209,8 @@ eval(char const * expr);
 /*
  *  Extracted from funcFor.c
  */
-static for_state_t *
-new_for_context(void);
-
 static void
-free_for_context(bool everything);
+free_for_context(int pop_ct);
 
 /*
  *  Extracted from functions.c
@@ -243,7 +234,7 @@ load_pseudo_mac(char const * text, char const * fname);
  *  Extracted from tpLoad.c
  */
 static templ_t *
-find_tpl(char const * pzTemplName);
+find_tpl(char const * tpl_name);
 
 static tSuccess
 find_file(char const * in_name,
